<?php

class backup_amiserv5 extends backup_component {

	public function name() {
		return 'amiserv5';
	}

	public function optional() {
		return false;
	}

	public function backup($tmpdir) {
		$archives = [];
		
		$this->backup_database(
			'amiserv5',
			$archives[] = "{$tmpdir}/amiserv5.sql.gz"
		);

		if (file_exists($dirname = "/etc/amiserv5")) {
			$this->backup_folder($dirname, $archive = "{$tmpdir}/amiserv5.tar.gz");
			$archives[] = $archive;
		}
		
		if (file_exists($dirname = "/etc/ipconnect/amiserv5.ver")) {
			$archive = "{$tmpdir}/ipconn_amiserv.tar.gz";
			static::exec(
				"tar czPf {$archive} -C /etc/ipconnect amiserv5.ver --acls --ignore-failed-read "
			);
			$archives[] = $archive;
		}
		return $archives;
	}

	public function pre_restore($tmpdir) {
		if (file_exists("{$tmpdir}/amiserv5.sql.gz")) {
			$this->drop_database('amiserv5');
		}
	}

	public function restore($tmpdir) {
		if (file_exists($archive = "{$tmpdir}/amiserv5.sql.gz")) {
			$this->restore_database($archive, 'amiserv5');
		}

		if (file_exists($archive = "{$tmpdir}/amiserv5.tar.gz")) {
			$this->restore_folder($archive, '/etc/amiserv5');
		}
		
		if (file_exists($archive = "{$tmpdir}/ipconn_amiserv.tar.gz")) {
			$this->restore_folder($archive, '/etc/ipconnect');
		}
	}

	public function post_restore($tmpdir) {
		if (file_exists('/usr/share/amiserv5/InstallScripts/after_update.sh')) {
			$this->exec('/usr/share/amiserv5/InstallScripts/after_update.sh');
		}
	}
}

?>
