#!/bin/bash
PRODUCTNAME="amiserv5"
TMPDIR="/tmp/amiserv5"
INSTALLDIR="/usr/share"
IPCDIR="/etc/ipconnect"
OLDVERSION=-1
NEWVERSION=-1
MAJORVERSION=5

mkdir -p "$TMPDIR"
mkdir -p "$IPCDIR"

if [ -e "$IPCDIR/$PRODUCTNAME.ver" ]
then
	OLDVERSION=$(cat "$IPCDIR/$PRODUCTNAME.ver" |cut -d"." -f2)
fi
NEWVERSION=$(head -n 1 "$INSTALLDIR/$PRODUCTNAME/version.txt" |cut -d"." -f2)
echo "-- Updating from $MAJORVERSION.$OLDVERSION to $MAJORVERSION.$NEWVERSION"

chmod +x "$INSTALLDIR/$PRODUCTNAME/InstallScripts/after_remove.sh"
chmod +x "$INSTALLDIR/$PRODUCTNAME/InstallScripts/after_update.sh"
chmod +x "$INSTALLDIR/$PRODUCTNAME/InstallScripts/before_remove.sh"
chmod +x "$INSTALLDIR/$PRODUCTNAME/InstallScripts/before_update.sh"

#On va faire une boucle à partir de "ancienne version + 1" jusqu'a la derniere version incluse
i=$(($OLDVERSION+1))
if [ $OLDVERSION -eq $NEWVERSION ]
then
	i=$OLDVERSION;
	echo "-- Updating same version but different revision, reexecuting patch of $i"
fi

while [ $i -le $NEWVERSION ]
do
	echo "-- Executing patch $MAJORVERSION.$i"
	find "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i" -name '*' -exec dos2unix {} 2> /dev/null \;
	bash "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i/update.sh"
	i=$(($i+1))
done

if [ -e "$TMPDIR/AmiServ5Service.exe.config.old" ]
then
	echo "-- Restoring .config file"
	rm -f "$INSTALLDIR/$PRODUCTNAME/AmiServ5Service.exe.config"
	mv -f "$TMPDIR/AmiServ5Service.exe.config.old" "$INSTALLDIR/$PRODUCTNAME/AmiServ5Service.exe.config"
fi

if [ ! -e "$INSTALLDIR/$PRODUCTNAME/AmiServ5Service.exe.config" ]
then
	echo "-- Creating $PRODUCTNAME service configuration file"
	cp "$INSTALLDIR/$PRODUCTNAME/App.config.template" "$INSTALLDIR/$PRODUCTNAME/AmiServ5Service.exe.config"
fi


echo "-- Creating magik keys"
if [ -L "$IPCDIR/magik" ]
then
	unlink "$IPCDIR/magik"
fi
rm -rf "$INSTALLDIR/$PRODUCTNAME/magik"
mkdir "$INSTALLDIR/$PRODUCTNAME/magik"
ln -s "$INSTALLDIR/$PRODUCTNAME/magik" "$IPCDIR/magik"
uuidgen > "$INSTALLDIR/$PRODUCTNAME/magik/performance"
chmod o+r "$INSTALLDIR/$PRODUCTNAME/magik/performance"
chmod o+r "$INSTALLDIR/$PRODUCTNAME/magik/performance"

systemctl daemon-reload
systemctl restart amiserv5

echo "$MAJORVERSION.$NEWVERSION" > "$IPCDIR/$PRODUCTNAME.ver"
echo "-- Update finished"

rm -rf "$TMPDIR"
exit